@@ -6,17 +6,18 @@ import java.awt.Dimension;
 import java.awt.Graphics;
 import java.awt.Graphics2D;
 import java.awt.Point;
-import java.awt.Rectangle;
 import java.awt.geom.AffineTransform;
 import java.awt.print.PageFormat;
 import java.awt.print.Printable;
 import java.util.ArrayList;
+import java.util.Collection;
 import java.util.List;
 import java.util.Timer;
 import java.util.TimerTask;
-import java.util.Vector;
 
-import javax.swing.JPanel;
+import javax.swing.JComponent;
+import javax.swing.JLayeredPane;
+import javax.swing.JScrollBar;
 import javax.swing.JScrollPane;
 import javax.swing.RepaintManager;
 import javax.swing.ScrollPaneConstants;
@@ -26,34 +27,49 @@ import org.apache.log4j.Logger;
 import com.baselet.control.Constants;
 import com.baselet.control.Constants.Program;
 import com.baselet.control.Constants.RuntimeType;
+import com.baselet.control.DiagramNotification;
 import com.baselet.control.Utils;
-import com.baselet.element.DiagramNotification;
+import com.baselet.diagram.draw.geom.Rectangle;
 import com.baselet.element.GridElement;
+import com.baselet.element.Group;
+import com.baselet.element.OldGridElement;
 import com.baselet.gui.StartUpHelpText;
 import com.baselet.gui.listener.ScrollbarListener;
+import com.baselet.gui.standalone.FileDrop;
+import com.baselet.gui.standalone.FileDropListener;
 import com.umlet.element.Relation;
+import com.umlet.element.experimental.ComponentSwing;
+import com.umlet.element.experimental.ElementFactory;
 
 @SuppressWarnings("serial")
-public class DrawPanel extends JPanel implements Printable {
-
-	private final static Logger log = Logger.getLogger(Utils.getClassName());
+public class DrawPanel extends JLayeredPane implements Printable {
+	
+	private static final Logger log = Logger.getLogger(DrawPanel.class);
 
 	private Point origin;
 	private JScrollPane _scr;
-	private Selector selector;
+	private SelectorOld selector;
 	private DiagramHandler handler;
-	private List<DiagramNotification> notifications;
+
+	private List<GridElement> gridElements = new ArrayList<GridElement>();
 
 	public DrawPanel(DiagramHandler handler) {
 		this.handler = handler;
 		// AB: Origin is used to track diagram movement in Cut Command
 		this.origin = new Point();
 		this.setLayout(null);
-		this.setBackground(Color.white);
+		this.setBackground(Color.WHITE);
+		this.setOpaque(true);
 		// If this is not a palette, create a StartupHelpText
-		if (!(handler instanceof PaletteHandler)) this.add(new StartUpHelpText(this));
-		this.selector = new Selector(this);
-		this.notifications = new ArrayList<DiagramNotification>();
+		if (!(handler instanceof PaletteHandler)) {
+			StartUpHelpText startupHelpText = new StartUpHelpText(this);
+			if (Program.RUNTIME_TYPE != RuntimeType.BATCH) { //Batchmode doesn't need drag&drop. Also fixes Issue 81
+				@SuppressWarnings("unused")
+				FileDrop fd = new FileDrop(startupHelpText, new FileDropListener());
+			}
+			this.add(startupHelpText);
+		}
+		this.selector = new SelectorOld(this);
 		JScrollPane p = new JScrollPane() {
 			@Override
 			public void setEnabled(boolean en) {
@@ -62,11 +78,9 @@ public class DrawPanel extends JPanel implements Printable {
 			}
 		};
 		p.getHorizontalScrollBar().setUnitIncrement(50); // Using mousewheel on bar or click on arrow
-		p.getHorizontalScrollBar().setBlockIncrement(20); // click in area without bar
 		p.getHorizontalScrollBar().setSize(0, 15);
 		p.setHorizontalScrollBarPolicy(ScrollPaneConstants.HORIZONTAL_SCROLLBAR_AS_NEEDED);
 		p.getVerticalScrollBar().setUnitIncrement(50);
-		p.getVerticalScrollBar().setBlockIncrement(20);
 		p.getVerticalScrollBar().setSize(15, 0);
 		p.setVerticalScrollBarPolicy(ScrollPaneConstants.VERTICAL_SCROLLBAR_AS_NEEDED);
 
@@ -125,7 +139,7 @@ public class DrawPanel extends JPanel implements Printable {
 	 *            the entities which should be included
 	 * @return Rectangle which contains all entities with border space
 	 */
-	public Rectangle getContentBounds(int borderSpace, Vector<GridElement> entities) {
+	public Rectangle getContentBounds(int borderSpace, Collection<GridElement> entities) {
 		if (entities.size() == 0) return new Rectangle(0, 0, 0, 0);
 		
 		int minx = Integer.MAX_VALUE;
@@ -133,31 +147,32 @@ public class DrawPanel extends JPanel implements Printable {
 		int maxx = 0;
 		int maxy = 0;
 
-		for (int i = 0; i < entities.size(); i++) {
-			GridElement e = entities.elementAt(i);
-			minx = Math.min(minx, e.getX() - borderSpace);
-			miny = Math.min(miny, e.getY() - borderSpace);
-			maxx = Math.max(maxx, e.getX() + e.getWidth() + borderSpace);
-			maxy = Math.max(maxy, e.getY() + e.getHeight() + borderSpace);
+		for (GridElement e : entities) {
+			minx = Math.min(minx, e.getRectangle().x - borderSpace);
+			miny = Math.min(miny, e.getRectangle().y - borderSpace);
+			maxx = Math.max(maxx, e.getRectangle().x + e.getRectangle().width + borderSpace);
+			maxy = Math.max(maxy, e.getRectangle().y + e.getRectangle().height + borderSpace);
 		}
 		return new Rectangle(minx, miny, maxx - minx, maxy - miny);
 	}
 
-	public void paintEntitiesIntoGraphics2D(Graphics2D g2d, Vector<GridElement> entitiesToPaint) {
-		boolean entityWasSelected = false;
-		for (GridElement entity : entitiesToPaint) {
-			if (entity.isSelected()) entityWasSelected = true;
-			int x = entity.getX();
-			int y = entity.getY();
-			g2d.translate(x, y);
-			if (entityWasSelected) entity.onDeselected(); // If entity was selected deselect it before painting
-			entity.paint(g2d);
-			if (entityWasSelected) { // and select it afterwards. Also reset boolean variable to false
-				entity.onSelected();
-				entityWasSelected = false;
+	public void paintEntitiesIntoGraphics2D(Graphics2D g2d, Collection<GridElement> entities) {
+		JLayeredPane tempPanel = new JLayeredPane();
+		for (GridElement entity : entities) {
+			GridElement clone = ElementFactory.createCopy(entity);
+			com.umlet.element.experimental.Component component = clone.getComponent();
+			//Issue 138: when PDF and Swing Export draw on (0,0) a part of the drawn image is cut, therefore it's displaced by 0.5px in that case
+			if (component instanceof ComponentSwing) {
+				((ComponentSwing) component).translateForExport();
+			} else if (component instanceof OldGridElement) {
+				((OldGridElement) component).translateForExport();
 			}
-			g2d.translate(-x, -y);
+			tempPanel.add((Component) component, clone.getLayer());
 		}
+		tempPanel.validate();
+		tempPanel.setBackground(Color.WHITE);
+		tempPanel.setSize(Integer.MAX_VALUE, Integer.MAX_VALUE);
+		tempPanel.update(g2d);
 	}
 
 	@Override
@@ -167,7 +182,7 @@ public class DrawPanel extends JPanel implements Printable {
 			Graphics2D g2d = (Graphics2D) g;
 			RepaintManager currentManager = RepaintManager.currentManager(this);
 			currentManager.setDoubleBufferingEnabled(false);
-			Rectangle bounds = this.getContentBounds(Constants.PRINTPADDING, getAllEntities());
+			Rectangle bounds = this.getContentBounds(Constants.printPadding, getAllEntities());
 			g2d.translate(pageFormat.getImageableX(), pageFormat.getImageableY());
 			AffineTransform t = g2d.getTransform();
 			double scale = Math.min(pageFormat.getImageableWidth() / bounds.width,
@@ -184,33 +199,44 @@ public class DrawPanel extends JPanel implements Printable {
 		}
 	}
 
-	public Vector<GridElement> getAllEntities() {
-		Vector<GridElement> v = new Vector<GridElement>();
-		for (int i = 0; i < this.getComponentCount(); i++) {
-			Component c = this.getComponent(i);
-			if (c instanceof GridElement) v.add((GridElement) c);
+	public List<GridElement> getAllEntities() {
+		return gridElements;
+	}
+	
+	/**
+	 * Groups form a tree structure, therefore this method returns only elements which are not part of the group.
+	 * Elements which are part of a group must be retrieved from the group using {@link Group#getMembers()}
+	 */
+	public List<GridElement> getAllEntitiesWithGroupsAsTree() {
+		List<GridElement> elementsToDraw = new ArrayList<GridElement>(gridElements);
+		for (GridElement e : gridElements) {
+			if (e instanceof Group) elementsToDraw.removeAll(((Group) e).getMembers());
 		}
-		return v;
+		return elementsToDraw;
 	}
 
-	public Vector<GridElement> getAllEntitiesNotInGroup() {
-		Vector<GridElement> entities = new Vector<GridElement>();
+	public List<Relation> getAllRelations() {
+		return getAll(Relation.class);
+	}
+	
+	@SuppressWarnings("unchecked")
+	private <T extends GridElement> List<T> getAll(Class<T> filtered) {
+		List<T> gridElementsToReturn = new ArrayList<T>();
+		for (GridElement e : getAllEntities()) {
+				if (e.getClass().equals(filtered)) gridElementsToReturn.add((T) e);
+		}
+		return gridElementsToReturn;
+	}
+
+	public List<GridElement> getAllEntitiesNotInGroup() {
+		List<GridElement> entities = new ArrayList<GridElement>();
 		for (GridElement e : getAllEntities()) {
 			if (!e.isPartOfGroup()) entities.add(e);
 		}
 		return entities;
 	}
 
-	public Vector<Relation> getAllRelations() {
-		Component[] tmp = this.getComponents();
-		Vector<Relation> ret = new Vector<Relation>();
-		for (int i = 0; i < tmp.length; i++) {
-			if (tmp[i] instanceof Relation) ret.add((Relation) tmp[i]);
-		}
-		return ret;
-	}
-
-	public Selector getSelector() {
+	public SelectorOld getSelector() {
 		return this.selector;
 	}
 
@@ -235,7 +261,7 @@ public class DrawPanel extends JPanel implements Printable {
 		Rectangle diaWithoutWhite = getContentBounds(0, getAllEntities());
 		// We must adjust the components and the view by a certain factor
 		int adjustWidth = 0;
-		if (diaWithoutWhite.getX() < 0) adjustWidth = (int) diaWithoutWhite.getX();
+		if (diaWithoutWhite.getX() < 0) adjustWidth = diaWithoutWhite.getX();
 
 		int adjustHeight = 0;
 		if (diaWithoutWhite.getY() < 0) adjustHeight = (int) diaWithoutWhite.getY();
@@ -317,10 +343,8 @@ public class DrawPanel extends JPanel implements Printable {
 
 		moveOrigin(newX, newY);
 
-		for (int i = 0; i < this.getComponents().length; i++) {
-			Component c = this.getComponent(i);
-			if (c instanceof GridElement) // We remove whitespace only for entities
-			c.setLocation(handler.realignToGrid(false, c.getX() - newX), handler.realignToGrid(false, c.getY() - newY));
+		for (GridElement ge : getAllEntities()) {
+			ge.setLocation(handler.realignToGrid(false, ge.getRectangle().x - newX), handler.realignToGrid(false, ge.getRectangle().y - newY));
 		}
 
 		changeViewPosition(-newX, -newY);
@@ -358,11 +382,13 @@ public class DrawPanel extends JPanel implements Printable {
 		if ((_scr.getHorizontalScrollBar().getValue() < handler.getGridSize()) && ((diaWithoutWhite.getX() + diaWithoutWhite.getWidth()) <= (viewSize.getWidth() + verSbWidth))) setHorizontalScrollbarVisibility(false);
 		// This is needed to hide the scrollbar if it's only scrollable by a value lower than the gridsize. Otherwise this scrollbar would remain visible to avoid grid-jumps of the diagram (only on the lower right corner)
 		// We also hide it if the horizontal scrollbar has lower than gridsize && the viewable diagrampanel width plus the horizontal scrollbar value is equal the right end of the diagram without whitespace
-		else if ((_scr.getHorizontalScrollBar().getValue() < handler.getGridSize()) && (getViewableDiagrampanelSize().getWidth() + _scr.getHorizontalScrollBar().getValue() == diaWithoutWhite.getX() + diaWithoutWhite.getWidth())) setHorizontalScrollbarVisibility(false);
+		else if ((_scr.getHorizontalScrollBar().getValue() < handler.getGridSize()) && (getViewableDiagrampanelSize().width + _scr.getHorizontalScrollBar().getValue() == diaWithoutWhite.getX() + diaWithoutWhite.getWidth())) {
+			setHorizontalScrollbarVisibility(false);
+		}
 		else setHorizontalScrollbarVisibility(true);
 
 		if ((_scr.getVerticalScrollBar().getValue() < handler.getGridSize()) && ((diaWithoutWhite.getY() + diaWithoutWhite.getHeight()) <= (viewSize.getHeight() + horSbHeight))) setVerticalScrollbarVisibility(false);
-		else if ((_scr.getVerticalScrollBar().getValue() < handler.getGridSize()) && (getViewableDiagrampanelSize().getHeight() + _scr.getVerticalScrollBar().getValue() == diaWithoutWhite.getY() + diaWithoutWhite.getHeight())) setVerticalScrollbarVisibility(false);
+		else if ((_scr.getVerticalScrollBar().getValue() < handler.getGridSize()) && (getViewableDiagrampanelSize().height + _scr.getVerticalScrollBar().getValue() == diaWithoutWhite.getY() + diaWithoutWhite.getHeight())) setVerticalScrollbarVisibility(false);
 		else setVerticalScrollbarVisibility(true);
 
 		// REMOVED TO FIX JUMPING PALETTE ENTRIES AT COPYING/CUTTING
@@ -389,13 +415,11 @@ public class DrawPanel extends JPanel implements Printable {
 	}
 
 	private boolean isHorizontalScrollbarVisible() {
-		if (_scr.getHorizontalScrollBarPolicy() == ScrollPaneConstants.HORIZONTAL_SCROLLBAR_ALWAYS) return true;
-		else return false;
+		return _scr.getHorizontalScrollBarPolicy() == ScrollPaneConstants.HORIZONTAL_SCROLLBAR_ALWAYS;
 	}
 
 	private boolean isVerticalScrollbarVisible() {
-		if (_scr.getVerticalScrollBarPolicy() == ScrollPaneConstants.VERTICAL_SCROLLBAR_ALWAYS) return true;
-		else return false;
+		return _scr.getVerticalScrollBarPolicy() == ScrollPaneConstants.VERTICAL_SCROLLBAR_ALWAYS;
 	}
 
 	private void drawGrid(Graphics2D g2d) {
@@ -443,27 +467,20 @@ public class DrawPanel extends JPanel implements Printable {
 		// g2.setTransform(t);
 
 		// drawDevHelpLines((Graphics2D) g);
+		
+		// check if layers have changed and update them
+		for (GridElement ge : gridElements) {
+			if (!ge.getLayer().equals(getLayer((JComponent) ge.getComponent()))) {
+				setLayer((JComponent) ge.getComponent(), ge.getLayer());
+			}
+		}
+		
 		Graphics2D g2d = (Graphics2D) g;
 		g2d.setRenderingHints(Utils.getUxRenderingQualityHigh(true));
 		if (Constants.show_grid) drawGrid(g2d);
 		super.paintComponents(g);
 	}
 
-	public void showNotification(String message) {
-
-		// There are no notifications on palette panels
-		if (getHandler() instanceof PaletteHandler) return;
-
-		if (!notifications.isEmpty()) {
-			for (DiagramNotification n : notifications)
-				this.remove(n);
-		}
-
-		DiagramNotification notification = new DiagramNotification(this.getHandler(), message);
-		notifications.add(notification);
-		this.add(notification);
-	}
-
 	/**
 	 * AB: Returns a copy of the actual origin zoomed to 100%.
 	 * Origin marks a point that tracks changes of the diagram panel size and can
@@ -490,7 +507,7 @@ public class DrawPanel extends JPanel implements Printable {
 	 * @return a point that marks the diagram origin.
 	 */
 	public Point getOrigin() {
-		log.debug("Diagram origin: " + origin);
+		log.trace("Diagram origin: " + origin);
 		return new Point(origin);
 	}
 
@@ -499,7 +516,7 @@ public class DrawPanel extends JPanel implements Printable {
 	 * This method is mainly used by updatePanelAndScrollBars() to keep track of the panels size changes.
 	 */
 	public void moveOrigin(int dx, int dy) {
-		log.debug("Move origin to: " + origin);
+		log.trace("Move origin to: " + origin);
 		this.origin.translate(handler.realignToGrid(false, dx), handler.realignToGrid(false, dy));
 	}
 
@@ -514,7 +531,48 @@ public class DrawPanel extends JPanel implements Printable {
 	 *            the new grid size
 	 */
 	public void zoomOrigin(int oldGridSize, int newGridSize) {
-		log.debug("Zoom origin to: " + origin);
+		log.trace("Zoom origin to: " + origin);
 		origin.setLocation((origin.x * newGridSize) / oldGridSize, (origin.y * newGridSize) / oldGridSize);
 	}
+
+	public void removeElement(GridElement gridElement) {
+		gridElements.remove(gridElement);
+		remove((Component) gridElement.getComponent());
+	}
+
+	public void addElement(GridElement gridElement) {
+		gridElements.add(gridElement);
+		add((Component) gridElement.getComponent(), gridElement.getLayer());
+	}
+	
+	public void updateElements() {
+		for (GridElement e : gridElements) {
+			e.updateModelFromText();
+		}
+	}
+
+	public GridElement getElementToComponent(Component component) {
+		for (GridElement e : gridElements) {
+			if (e.getComponent().equals(component)) return e;
+		}
+		return null;
+	}
+	
+	public void scroll(int amount) {
+		JScrollBar scrollBar = _scr.getVerticalScrollBar();
+		int increment = scrollBar.getUnitIncrement();
+		scrollBar.setValue(scrollBar.getValue() + amount * increment);
+	}
+
+	private DiagramNotification notification;
+	public void setNotification(DiagramNotification newNotification) {
+		if (notification != null) {
+			remove(notification);
+		}
+	
+		this.notification = newNotification;
+		add(notification);
+		
+		repaint();
+	}
 }
