@@ -5,6 +5,7 @@ import java.util.Vector;
 import com.baselet.control.ClipBoard;
 import com.baselet.diagram.DiagramHandler;
 import com.baselet.element.GridElement;
+import com.umlet.element.experimental.ElementFactory;
 
 
 public class Copy extends Command {
@@ -21,16 +22,18 @@ public class Copy extends Command {
 		// dont execute super.execute() because no change of diagram is required.
 		if (this.entities == null) {
 			this.entities = new Vector<GridElement>();
-			for (GridElement e : handler.getDrawPanel().getSelector().getSelectedEntities())
-				this.entities.add(e.CloneFromMe());
+			for (GridElement e : handler.getDrawPanel().getSelector().getSelectedElements())
+				this.entities.add(ElementFactory.createCopy(e));
 		}
 
 		// if (entities.isEmpty()) return; UNCOMMENTED TO ALLOW COPY FULL DIAGRAM TO CLIPBOARD WITHOUT SELECTING ANYTHING
 		ClipBoard.getInstance().copy(this.entities, handler);
 	}
 
+
 	@Override
-	public void undo(DiagramHandler handler) {
-		super.undo(handler);
+	public boolean isChangingDiagram() {
+		return false;
 	}
+	
 }
