@@ -22,9 +22,9 @@ public class CreateGroup extends Command {
 		super.execute(handler);
 		if (this._entities == null) {
 			this._entities = new Vector<GridElement>();
-			this._entities.addAll(handler.getDrawPanel().getSelector().getSelectedEntities());
+			this._entities.addAll(handler.getDrawPanel().getSelector().getSelectedElements());
 		}
-		_group.setHandler(handler);
+		handler.setHandlerAndInitListeners(_group);
 		_group.group(this._entities);
 	}
 
