@@ -40,13 +40,12 @@ import org.apache.log4j.Logger;
 import com.baselet.control.Constants;
 import com.baselet.control.Constants.Program;
 import com.baselet.control.Main;
-import com.baselet.control.Utils;
 import com.baselet.diagram.io.DiagramFileHandler;
 
 public class MailPanel extends JPanel {
 
-	private final static Logger log = Logger.getLogger(Utils.getClassName());
-
+	private static final Logger log = Logger.getLogger(MailPanel.class);
+	
 	private static final long serialVersionUID = 1L;
 
 	/**
@@ -169,7 +168,7 @@ public class MailPanel extends JPanel {
 
 	private void initAndFillComponents() {
 
-		ta_text.setText(Constants.DEFAULT_MAILTEXT);
+		ta_text.setText(Constants.getDefaultMailtext());
 
 		cb_pwSave.setText("save in config");
 		cb_attachXml.setText("attach " + Program.EXTENSION.toUpperCase());
