@@ -6,14 +6,16 @@ import java.awt.Graphics;
 
 import javax.swing.Icon;
 
-import com.baselet.control.Utils;
+import com.baselet.diagram.draw.helper.ColorOwn;
+import com.baselet.diagram.draw.helper.ColorOwn.Transparency;
+import com.baselet.diagram.draw.swing.Converter;
 
 public class PlainColorIcon implements Icon {
 
 	private Color color;
 
 	public PlainColorIcon(String color) {
-		this.color = Utils.getColor(color);
+		this.color = Converter.convert(ColorOwn.forString(color, Transparency.FOREGROUND));
 	}
 
 	@Override
