@@ -46,6 +46,7 @@ import com.baselet.gui.standalone.FileDrop.TransferableObject;
  * @author rharder@users.sf.net
  * @version 1.0.1
  */
+@SuppressWarnings("all")
 public class FileDrop {
 	private transient javax.swing.border.Border normalBorder;
 	private transient java.awt.dnd.DropTargetListener dropListener;
@@ -729,14 +730,14 @@ public class FileDrop {
 		 * 
 		 * @since 1.1
 		 */
-		public final static String MIME_TYPE = "application/x-net.iharder.dnd.TransferableObject";
+		public static final String MIME_TYPE = "application/x-net.iharder.dnd.TransferableObject";
 
 		/**
 		 * The default {@link java.awt.datatransfer.DataFlavor} for {@link TransferableObject} has the representation class <tt>net.iharder.dnd.TransferableObject.class</tt> and the MIME type <tt>application/x-net.iharder.dnd.TransferableObject</tt>.
 		 * 
 		 * @since 1.1
 		 */
-		public final static java.awt.datatransfer.DataFlavor DATA_FLAVOR =
+		public static final java.awt.datatransfer.DataFlavor DATA_FLAVOR =
 				new java.awt.datatransfer.DataFlavor(FileDrop.TransferableObject.class, MIME_TYPE);
 
 		private Fetcher fetcher;
