@@ -27,7 +27,9 @@ public class SearchListener implements KeyListener, MouseMotionListener {
 		if (e.getKeyCode() == KeyEvent.VK_ENTER) {
 			JTextField search = (JTextField) e.getComponent();
 			DiagramHandler h = Main.getInstance().getDiagramHandler();
-			if ((h != null) && !"".equals(search) && (search != null)) h.getController().executeCommand(new Search(search.getText()));
+			if ((h != null) && search != null && ! "".equals(search.getText())) {
+				h.getController().executeCommand(new Search(search.getText()));
+			}
 			Main.getInstance().getGUI().enableSearch(false);
 		}
 		else if (e.getKeyCode() == KeyEvent.VK_ESCAPE) Main.getInstance().getGUI().enableSearch(false);
