@@ -15,41 +15,45 @@ import java.awt.geom.Line2D;
 import java.awt.geom.QuadCurve2D;
 import java.awt.geom.RoundRectangle2D;
 import java.util.Arrays;
+import java.util.HashSet;
 import java.util.List;
+import java.util.Set;
 import java.util.Vector;
 
 import com.baselet.control.Constants;
-import com.baselet.control.Constants.AlignHorizontal;
-import com.baselet.control.Constants.AlignVertical;
-import com.baselet.control.Constants.LineType;
+import com.baselet.control.Main;
 import com.baselet.control.Utils;
+import com.baselet.control.enumerations.AlignHorizontal;
+import com.baselet.control.enumerations.Direction;
+import com.baselet.control.enumerations.LineType;
+import com.baselet.diagram.draw.helper.ColorOwn;
+import com.baselet.diagram.draw.helper.ColorOwn.Transparency;
+import com.baselet.diagram.draw.swing.Converter;
 import com.baselet.element.GridElement;
+import com.baselet.element.OldGridElement;
 
 
 @SuppressWarnings("serial")
-public abstract class CustomElement extends GridElement {
+public abstract class CustomElement extends OldGridElement {
 
 	private class Text {
 		private String text;
 		private int x, y;
 		private AlignHorizontal align;
-		private AlignVertical valign;
 		private Integer fixedSize;
 
-		private Text(String text, int x, int y, AlignHorizontal align, AlignVertical valign) {
+		private Text(String text, int x, int y, AlignHorizontal align) {
 			this.text = text;
 			this.x = x;
 			this.y = y;
 			this.align = align;
-			this.valign = valign;
 		}
 
-		private Text(String text, int x, int y, AlignHorizontal align, AlignVertical valign, Integer fixedSize) {
+		private Text(String text, int x, int y, AlignHorizontal align, Integer fixedSize) {
 			this.text = text;
 			this.x = x;
 			this.y = y;
 			this.align = align;
-			this.valign = valign;
 			this.fixedSize = fixedSize; // some texts should not be zoomed
 		}
 	}
@@ -77,6 +81,7 @@ public abstract class CustomElement extends GridElement {
 
 	private boolean specialLine, specialFgColor, specialBgColor;
 	private boolean wordWrap = false;
+	private boolean allowResize = true;
 
 	public CustomElement() {
 		this.shapes = new Vector<StyleShape>();
@@ -99,7 +104,7 @@ public abstract class CustomElement extends GridElement {
 		g2.setComposite(this.composites[1]);
 
 		for (StyleShape s : this.shapes) {
-			specialBgColor = ((s.getBgColor() != bgColor));
+			specialBgColor = !(s.getBgColor().equals(bgColor));
 			if (specialBgColor) {
 				g2.setColor(s.getBgColor());
 				g2.setComposite(AlphaComposite.getInstance(AlphaComposite.SRC_OVER, s.getAlpha()));
@@ -116,11 +121,11 @@ public abstract class CustomElement extends GridElement {
 
 		for (StyleShape s : this.shapes) {
 			specialLine = ((s.getLineType() != LineType.SOLID) || (s.getLineThickness() != Constants.DEFAULT_LINE_THICKNESS));
-			specialFgColor = (s.getFgColor() != Constants.DEFAULT_FOREGROUND_COLOR);
+			specialFgColor = !s.getFgColor().equals(Converter.convert(ColorOwn.DEFAULT_FOREGROUND));
 
 			if (specialLine) g2.setStroke(Utils.getStroke(s.getLineType(), s.getLineThickness()));
 			if (specialFgColor) {
-				if (isSelected) g2.setColor(Constants.DEFAULT_SELECTED_COLOR);
+				if (Main.getHandlerForElement(this).getDrawPanel().getSelector().isSelected(this)) g2.setColor(Converter.convert(ColorOwn.SELECTION_FG));
 				else g2.setColor(s.getFgColor());
 			}
 			this.g2.draw(s.getShape());
@@ -131,12 +136,12 @@ public abstract class CustomElement extends GridElement {
 		for (Text t : this.texts) {
 			boolean applyZoom = true;
 			if (t.fixedSize != null) {
-				getHandler().getFontHandler().setFontSize(t.fixedSize);
+				Main.getHandlerForElement(this).getFontHandler().setFontSize((double) t.fixedSize);
 				applyZoom = false;
 			}
-			this.getHandler().getFontHandler().writeText(this.g2, t.text, t.x, t.y, t.align, t.valign, applyZoom);
+			Main.getHandlerForElement(this).getFontHandler().writeText(this.g2, t.text, t.x, t.y, t.align, applyZoom);
 			if (t.fixedSize != null) {
-				getHandler().getFontHandler().resetFontSize();
+				Main.getHandlerForElement(this).getFontHandler().resetFontSize();
 			}
 		}
 
@@ -150,17 +155,17 @@ public abstract class CustomElement extends GridElement {
 
 		this.g2 = (Graphics2D) g;
 		composites = this.colorize(g2);
-		g2.setFont(this.getHandler().getFontHandler().getFont());
+		g2.setFont(Main.getHandlerForElement(this).getFontHandler().getFont());
 		g2.setColor(fgColor);
 
-		zoom = getHandler().getZoomFactor();
+		zoom = Main.getHandlerForElement(this).getZoomFactor();
 		if (zoom < 0.25) bugfix = true;
 		else bugfix = false;
 
 		// width and height must be zoomed back to 100% before any custom code is applied
-		temp = this.getWidth();
+		temp = this.getRectangle().width;
 		width = Math.round(temp / zoom); // use Math.round cause (int) would round down from 239.99998 to 240
-		temp = this.getHeight();
+		temp = this.getRectangle().height;
 		height = Math.round(temp / zoom);
 
 		// Set width and height on grid (used for manually resized custom elements mainly
@@ -187,12 +192,12 @@ public abstract class CustomElement extends GridElement {
 		// Resize elements if manual resize is not set
 		// if (!this.allowResize || (this.autoResizeandManualResizeEnabled() && !this.isManualResized())) {
 		// CHANGED: Resize every custom object by +1px to get consistent height and width
-		if (!bugfix) this.setSize(this.width + 1, this.height + 1);
+		if (!bugfix) this.setSize((this.width + 1), (this.height + 1));
 		// }
 	}
 
 	@Override
-	public final GridElement CloneFromMe() {
+	public GridElement CloneFromMe() {
 		CustomElement e = (CustomElement) super.CloneFromMe();
 		e.code = this.code;
 		return e;
@@ -201,9 +206,9 @@ public abstract class CustomElement extends GridElement {
 	@CustomFunction(param_defaults = "text,x,y")
 	protected final int print(String text, int x, int inY) {
 		int y = inY;
-		List<String> list = wordWrap ? Utils.splitString(text, (int) (width * zoom)) : Arrays.asList(new String[] {text});
+		List<String> list = wordWrap ? Utils.splitString(text, width, Main.getHandlerForElement(this)) : Arrays.asList(new String[] {text});
 		for (String s : list) {
-			this.texts.add(new Text(s, (int) (x * zoom), (int) (y * zoom), AlignHorizontal.LEFT, AlignVertical.BOTTOM));
+			this.texts.add(new Text(s, (int) (x * zoom), (int) (y * zoom), AlignHorizontal.LEFT));
 			y += textHeight();
 		}
 		return y - inY;
@@ -212,9 +217,9 @@ public abstract class CustomElement extends GridElement {
 	@CustomFunction(param_defaults = "text,y")
 	protected final int printLeft(String text, int inY) {
 		int y = inY;
-		List<String> list = wordWrap ? Utils.splitString(text, (int) (width * zoom)) : Arrays.asList(new String[] {text});
+		List<String> list = wordWrap ? Utils.splitString(text, width, Main.getHandlerForElement(this)) : Arrays.asList(new String[] {text});
 		for (String s : list) {
-			this.texts.add(new Text(s, ((int) this.getHandler().getFontHandler().getDistanceBetweenTexts()), (int) (y * zoom), AlignHorizontal.LEFT, AlignVertical.BOTTOM));
+			this.texts.add(new Text(s, ((int) Main.getHandlerForElement(this).getFontHandler().getDistanceBetweenTexts()), (int) (y * zoom), AlignHorizontal.LEFT));
 			y += textHeight();
 		}
 		return y - inY;
@@ -223,9 +228,9 @@ public abstract class CustomElement extends GridElement {
 	@CustomFunction(param_defaults = "text,y")
 	protected final int printRight(String text, int inY) {
 		int y = inY;
-		List<String> list = wordWrap ? Utils.splitString(text, (int) (width * zoom)) : Arrays.asList(new String[] {text});
+		List<String> list = wordWrap ? Utils.splitString(text, width, Main.getHandlerForElement(this)) : Arrays.asList(new String[] {text});
 		for (String s : list) {
-			this.texts.add(new Text(s, (int) ((width * zoom - this.textWidth(s, true))), (int) (y * zoom), AlignHorizontal.LEFT, AlignVertical.BOTTOM));
+			this.texts.add(new Text(s, (int) ((width * zoom - this.textWidth(s, true))), (int) (y * zoom), AlignHorizontal.LEFT));
 			y += textHeight();
 		}
 		return y - inY;
@@ -234,9 +239,9 @@ public abstract class CustomElement extends GridElement {
 	@CustomFunction(param_defaults = "text,y")
 	protected final int printCenter(String text, int inY) {
 		int y = inY;
-		List<String> list = wordWrap ? Utils.splitString(text, (int) (width * zoom)) : Arrays.asList(new String[] {text});
+		List<String> list = wordWrap ? Utils.splitString(text, width, Main.getHandlerForElement(this)) : Arrays.asList(new String[] {text});
 		for (String s : list) {
-			this.texts.add(new Text(s, (int) (((onGrid(width) * zoom - this.textWidth(s, true)) / 2)), (int) (y * zoom), AlignHorizontal.LEFT, AlignVertical.BOTTOM));
+			this.texts.add(new Text(s, (int) (((onGrid(width) * zoom - this.textWidth(s, true)) / 2)), (int) (y * zoom), AlignHorizontal.LEFT));
 			y += textHeight();
 		}
 		return y - inY;
@@ -245,28 +250,28 @@ public abstract class CustomElement extends GridElement {
 	@CustomFunction(param_defaults = "text,x,y,fixedFontSize")
 	protected final int printFixedSize(String text, int x, int inY, int fixedFontSize) {
 		int y = inY;
-		List<String> list = wordWrap ? Utils.splitString(text, width) : Arrays.asList(new String[] {text});
+		List<String> list = wordWrap ? Utils.splitString(text, width, Main.getHandlerForElement(this)) : Arrays.asList(new String[] {text});
 		for (String s : list) {
-		this.texts.add(new Text(s, x, y, AlignHorizontal.LEFT, AlignVertical.BOTTOM, fixedFontSize));
+		this.texts.add(new Text(s, x, y, AlignHorizontal.LEFT, fixedFontSize));
 		y += textHeight();
 		}
 		return y - inY;
 	}
 
 	@CustomFunction(param_defaults = "value")
-	protected final int onGrid(int value) {
+	protected final int onGrid(double value) {
 		return onGrid(value, false);
 	}
 
 	@CustomFunction(param_defaults = "value, roundUp")
-	protected final int onGrid(int value, boolean roundUp) {
+	protected final int onGrid(double value, boolean roundUp) {
 		if (value % 10 != 0) {
 			value -= (value % 10);
 			if (roundUp) value += 10;
 		}
 		// BUGFIX for 10% and 20% zoom: Otherwise a manual resized entity border wouldn't be visible because of the exclusion of line 146
 		if (bugfix) value--;
-		return value;
+		return (int) value;
 	}
 	
 	@CustomFunction(param_defaults = "value1,value2")
@@ -352,12 +357,12 @@ public abstract class CustomElement extends GridElement {
 
 	@CustomFunction(param_defaults = "y")
 	protected final void drawLineHorizontal(int y) {
-		this.shapes.add(new StyleShape(new Line2D.Float((int) (0 * zoom), (int) (y * zoom), getHandler().realignToGrid(false, (int) (width * zoom), true), (int) (y * zoom)), tmpLineType, tmpLineThickness, tmpFgColor, tmpBgColor, tmpAlpha));
+		this.shapes.add(new StyleShape(new Line2D.Float((int) (0 * zoom), (int) (y * zoom), Main.getHandlerForElement(this).realignToGrid(false, (int) (width * zoom), true), (int) (y * zoom)), tmpLineType, tmpLineThickness, tmpFgColor, tmpBgColor, tmpAlpha));
 	}
 
 	@CustomFunction(param_defaults = "x")
 	protected final void drawLineVertical(int x) {
-		this.shapes.add(new StyleShape(new Line2D.Float((int) (x * zoom), (int) (0 * zoom), (int) (x * zoom), getHandler().realignToGrid(false, (int) (height * zoom), true)), tmpLineType, tmpLineThickness, tmpFgColor, tmpBgColor, tmpAlpha));
+		this.shapes.add(new StyleShape(new Line2D.Float((int) (x * zoom), (int) (0 * zoom), (int) (x * zoom), Main.getHandlerForElement(this).realignToGrid(false, (int) (height * zoom), true)), tmpLineType, tmpLineThickness, tmpFgColor, tmpBgColor, tmpAlpha));
 	}
 
 	@CustomFunction(param_defaults = "polygon")
@@ -410,7 +415,7 @@ public abstract class CustomElement extends GridElement {
 
 	@CustomFunction(param_defaults = "foregroundColor")
 	protected final void setForegroundColor(String fgColorString) {
-		tmpFgColor = Utils.getColor(fgColorString);
+		tmpFgColor = Converter.convert(ColorOwn.forString(fgColorString, Transparency.FOREGROUND));
 		if (tmpFgColor == null) {
 			if (fgColorString.equals("fg")) tmpFgColor = fgColor;
 		}
@@ -418,13 +423,14 @@ public abstract class CustomElement extends GridElement {
 
 	@CustomFunction(param_defaults = "backgroundColor")
 	protected final void setBackgroundColor(String bgColorString) {
-		tmpBgColor = Utils.getColor(bgColorString);
+		// OldGridElements apply transparency for background explicitly, therefore don't apply it here
+		tmpBgColor = Converter.convert(ColorOwn.forString(bgColorString, Transparency.FOREGROUND));
 		if (tmpBgColor == null) {
 			if (bgColorString.equals("bg")) tmpBgColor = bgColor;
 		}
 //		 Transparency is 0% if none or 50% if anything else
-		if (bgColorString.equals("none")) tmpAlpha = Constants.ALPHA_FULL_TRANSPARENCY;
-		else tmpAlpha = Constants.ALPHA_MIDDLE_TRANSPARENCY;
+		if (bgColorString.equals("none")) tmpAlpha = OldGridElement.ALPHA_FULL_TRANSPARENCY;
+		else tmpAlpha = OldGridElement.ALPHA_MIDDLE_TRANSPARENCY;
 	}
 
 	@CustomFunction(param_defaults = "")
@@ -435,4 +441,15 @@ public abstract class CustomElement extends GridElement {
 		tmpBgColor = bgColor;
 		tmpAlpha = alphaFactor;
 	}
+
+	protected final void allowResize(boolean allow) {
+		this.allowResize = allow;
+	}
+	
+	@Override
+	public Set<Direction> getResizeArea(int x, int y) {
+		if (allowResize) return super.getResizeArea(x, y);
+		else return new HashSet<Direction>();
+	}
+	
 }
