@@ -1,24 +1,27 @@
 package com.umlet.element;
 
 import java.awt.Color;
-import java.awt.Composite;
-import java.awt.Dimension;
 import java.awt.Graphics;
 import java.awt.Graphics2D;
-import java.awt.Point;
 import java.awt.Polygon;
-import java.awt.Rectangle;
 import java.awt.font.TextLayout;
 import java.awt.geom.AffineTransform;
 import java.awt.geom.Area;
-import java.awt.geom.Rectangle2D;
 import java.util.Vector;
 
 import com.baselet.control.Constants;
-import com.baselet.control.Constants.LineType;
+import com.baselet.control.Main;
 import com.baselet.control.Utils;
+import com.baselet.control.enumerations.AlignHorizontal;
+import com.baselet.control.enumerations.LineType;
+import com.baselet.diagram.draw.geom.Point;
+import com.baselet.diagram.draw.geom.PointDouble;
+import com.baselet.diagram.draw.geom.Rectangle;
+import com.baselet.diagram.draw.swing.Converter;
 import com.baselet.element.GridElement;
-import com.baselet.element.StickingPolygon;
+import com.baselet.element.OldGridElement;
+import com.baselet.element.Selector;
+import com.baselet.element.sticking.StickingPolygon;
 import com.umlet.element.relation.Arrow;
 import com.umlet.element.relation.EmptyShape;
 import com.umlet.element.relation.Multiplicity;
@@ -29,7 +32,7 @@ import com.umlet.element.relation.Role;
 
 
 @SuppressWarnings("serial")
-public class Relation extends GridElement {
+public class Relation extends OldGridElement {
 
 	String beginQualifier;
 	String endQualifier;
@@ -116,25 +119,6 @@ public class Relation extends GridElement {
 	@Override
 	public void setAdditionalAttributes(String s) {
 		Vector<String> tmp = Utils.decomposeStringsIncludingEmptyStrings(s, Constants.DELIMITER_ADDITIONAL_ATTRIBUTES);
-		// 9 attributes, 4 for start/end point, 4 for x,y,w,h
-		/*
-		 * if (tmp.size()<17) throw new RuntimeException("Error in
-		 * Relation.setHiddenState(), state value = "+s);
-		 * beginQualifier=(String)tmp.elementAt(0);
-		 * endQualifier=(String)tmp.elementAt(1);
-		 * beginArrow=(String)tmp.elementAt(2);
-		 * endArrow=(String)tmp.elementAt(3);
-		 * beginMultiplicity=(String)tmp.elementAt(4);
-		 * endMultiplicity=(String)tmp.elementAt(5);
-		 * beginRole=(String)tmp.elementAt(6); endRole=(String)tmp.elementAt(7);
-		 * lineType=(String)tmp.elementAt(8);
-		 * int x=Integer.parseInt((String)tmp.elementAt(9)); int
-		 * y=Integer.parseInt((String)tmp.elementAt(10)); int
-		 * w=Integer.parseInt((String)tmp.elementAt(11)); int
-		 * h=Integer.parseInt((String)tmp.elementAt(12));
-		 * this.setBounds(x,y,w,h);
-		 */
-
 		for (int i = 0; i < tmp.size(); i = i + 2) {
 			int x = Integer.parseInt(tmp.elementAt(i));
 			int y = Integer.parseInt(tmp.elementAt(i + 1));
@@ -234,9 +218,9 @@ public class Relation extends GridElement {
 				else if (s.indexOf(">>") >= 0) {
 					endArrow = "<<";
 				}
-				// else if (s.indexOf("m>") >= 0) {
-				// endArrow = "crowsFoot";
-				// }
+				 else if (s.indexOf("m>") >= 0) {
+				 endArrow = "crowsFoot";
+				 }
 				else if (s.indexOf(">") >= 0) {
 					if (endArrow.equals("")) endArrow = "<";
 				}
@@ -253,9 +237,9 @@ public class Relation extends GridElement {
 				else if (s.indexOf("<<") >= 0) {
 					beginArrow = "<<";
 				}
-				// else if (s.indexOf("<m") >= 0) {
-				// beginArrow = "crowsFoot";
-				// }
+				 else if (s.indexOf("<m") >= 0) {
+				 beginArrow = "crowsFoot";
+				 }
 				else if (s.indexOf("<") >= 0) {
 					if (beginArrow.equals("")) beginArrow = "<";
 				}
@@ -364,20 +348,20 @@ public class Relation extends GridElement {
 				else if ((s.indexOf("-") >= 0) & (s.indexOf(".") >= s.indexOf("-"))) {
 					lineType = "-.";
 				}
-				else if (s.indexOf(".") >= 0) {
-					lineType = ".";
+				else if (s.indexOf(LineType.DASHED.getValue()) >= 0) {
+					lineType = LineType.DASHED.getValue();
 				}
-				else if (s.indexOf("-") >= 0) {
-					lineType = "-";
+				else if (s.indexOf(LineType.SOLID.getValue()) >= 0) {
+					lineType = LineType.SOLID.getValue();
 				}
-				else if(s.substring(3, s.length()).indexOf("=") >= 0) {
-					lineType = "=";
+				else if(s.substring(3, s.length()).indexOf(LineType.DOUBLE.getValue()) >= 0) {
+					lineType = LineType.DOUBLE.getValue();
 				}
-				else if(s.indexOf("::") >= 0) {
-					lineType = "::";
+				else if(s.indexOf(LineType.DOUBLE_DOTTED.getValue()) >= 0) {
+					lineType = LineType.DOUBLE_DOTTED.getValue();
 				}
-				else if(s.indexOf(":") >= 0) {
-					lineType = ":";
+				else if(s.indexOf(LineType.DOUBLE_DASHED.getValue()) >= 0) {
+					lineType = LineType.DOUBLE_DASHED.getValue();
 				}
 			}
 			else {
@@ -397,7 +381,7 @@ public class Relation extends GridElement {
 
 		for (int i = 1; i < points.size(); i++) {
 			pp_end = points.elementAt(i);
-			if (!r.contains(pp_end)) {
+			if (!r.contains(Converter.convert(pp_end))) {
 				// End point of intersecting line found
 				pp_start = points.elementAt(i - 1);
 
@@ -425,11 +409,11 @@ public class Relation extends GridElement {
 		int endx = pEnd.x;
 		int endy = pEnd.y;
 
-		for (int i = 0;; i++) {
+		for (@SuppressWarnings("unused") int i = 0;; i++) {
 			endx += vectorX;
 			endy += vectorY;
 			rMovable.setLocation(endx + centerDiffX, endy + centerDiffY);
-			if (!rFixed.intersects(rMovable)) break;
+			if (!rFixed.intersects(Converter.convert(rMovable))) break;
 		}
 
 		int newx = 0;
@@ -438,7 +422,7 @@ public class Relation extends GridElement {
 			newx = (endx + startx) / 2;
 			newy = (endy + starty) / 2;
 			rMovable.setLocation(newx + centerDiffX, newy + centerDiffY);
-			if (rFixed.intersects(rMovable)) {
+			if (rFixed.intersects(Converter.convert(rMovable))) {
 				startx = newx;
 				starty = newy;
 			}
@@ -454,7 +438,7 @@ public class Relation extends GridElement {
 
 	public boolean lineUp(Vector<Rectangle> shapes, Vector<Point> points, int hotspotx, int hotspoty) {
 
-		float zoom = getHandler().getZoomFactor();
+		float zoom = Main.getHandlerForElement(this).getZoomFactor();
 
 		// Remove point with the same coordinates
 		for (int i = points.size() - 1; i > 0; i--) {
@@ -477,7 +461,7 @@ public class Relation extends GridElement {
 				Point p = points.elementAt(0);
 				r.setLocation(p.x - hotspotx, p.y - hotspoty);
 			}
-			Area a = new Area(r);
+			Area a = new Area(Converter.convert(r));
 			tmpArea.add(a);
 
 			// rFixed=(Rectangle)shapes.elementAt(i);
@@ -509,8 +493,8 @@ public class Relation extends GridElement {
 				Point a2 = new Point(2 * diffA.x + diffB2.x, 2 * diffA.y
 						+ diffB2.y);
 
-				a1 = Utils.normalize(a1, (int) this.getHandler().getFontHandler().getFontSize());
-				a2 = Utils.normalize(a2, (int) this.getHandler().getFontHandler().getFontSize());
+				a1 = Utils.normalize(a1, (int) Main.getHandlerForElement(this).getFontHandler().getFontSize());
+				a2 = Utils.normalize(a2, (int) Main.getHandlerForElement(this).getFontHandler().getFontSize());
 
 				arrow.setArrowEndA(a1);
 				arrow.setArrowEndB(a2);
@@ -542,8 +526,8 @@ public class Relation extends GridElement {
 					// the point compared to each other
 					// (which means propX + propY = 1) and multiplies it with
 					// the second parameter...
-					newA1 = Utils.normalize(newA1, (int) this.getHandler().getFontHandler().getFontSize() * 2);
-					newA2 = Utils.normalize(newA2, (int) this.getHandler().getFontHandler().getFontSize() * 2);
+					newA1 = Utils.normalize(newA1, (int) Main.getHandlerForElement(this).getFontHandler().getFontSize() * 2);
+					newA2 = Utils.normalize(newA2, (int) Main.getHandlerForElement(this).getFontHandler().getFontSize() * 2);
 
 					arrow.setCrossEndA(newA1);
 					arrow.setCrossEndB(newA2);
@@ -619,7 +603,7 @@ public class Relation extends GridElement {
 			}
 
 			// ATTENTION: this Recangle will become the rFixed in the next loop
-			rMovable.setLocation(res);
+			rMovable.setLocation(res.x, res.y);
 		}
 
 		return true;
@@ -629,12 +613,11 @@ public class Relation extends GridElement {
 	 * A relation is only in range (= in the selection frame) if every relation point is in the selection frame
 	 */
 	@Override
-	public boolean isInRange(Point upperLeft, Dimension size) {
-		Rectangle2D rect1 = new Rectangle2D.Double(upperLeft.getX(), upperLeft.getY(), size.getWidth(), size.getHeight());
+	public boolean isInRange(Rectangle rect1) {
 		// Assume that the rect contains all relation points
 		for (Point p : getLinePoints()) {
 			// We must add the displacement from the top left corner of the drawpanel to the point coordinates
-			Point realPoint = new Point((int) (p.getX() + this.getX()), (int) (p.getY() + this.getY()));
+			Point realPoint = new Point((int) (p.getX() + this.getRectangle().x), (int) (p.getY() + this.getRectangle().y));
 			// If only one point is not in the selection rectangle, the method returns false
 			if (!rect1.contains(realPoint)) return false;
 		}
@@ -646,7 +629,7 @@ public class Relation extends GridElement {
 			Point x1 = getLinePoints().elementAt(i - 1);
 			Point x2 = getLinePoints().elementAt(i + 1);
 			Point p = getLinePoints().elementAt(i);
-			if (pyth(p, x1) + pyth(p, x2) < pyth(x1, x2) + 5) return true;
+			if (p.distance(x1) + p.distance(x2) < x1.distance(x2) + 5) return true;
 		}
 		return false;
 	}
@@ -655,28 +638,22 @@ public class Relation extends GridElement {
 		for (int i = 0; i < getLinePoints().size() - 1; i++) {
 			Point x1 = getLinePoints().elementAt(i);
 			Point x2 = getLinePoints().elementAt(i + 1);
-			if (pyth(p, x1) + pyth(p, x2) < pyth(x1, x2) + 5) return i + 1;
+			if (p.distance(x1) + p.distance(x2) < x1.distance(x2) + 5) return i + 1;
 		}
 		return -1;
 	}
 
 	public int getLinePoint(Point p) {
 
-		float zoom = getHandler().getZoomFactor();
+		float zoom = Main.getHandlerForElement(this).getZoomFactor();
 
 		for (int i = 0; i < getLinePoints().size(); i++) {
 			Point x = getLinePoints().elementAt(i);
-			if (pyth(p, x) < SELECTCIRCLESIZE * zoom) return i;
+			if (p.distance(x) < SELECTCIRCLESIZE * zoom) return i;
 		}
 		return -1;
 	}
 
-	private int pyth(Point x1, Point x2) {
-		int a = x1.x - x2.x;
-		int b = x1.y - x2.y;
-		return (int) Math.sqrt(a * a + b * b);
-	}
-
 	private <T> Vector<T> flipVector(Vector<T> v) {
 		Vector<T> ret = new Vector<T>();
 		for (int i = v.size() - 1; i >= 0; i--) {
@@ -686,20 +663,36 @@ public class Relation extends GridElement {
 	}
 
 	@Override
-	public boolean contains(Point p) {
+	public boolean contains(java.awt.Point p) {
+		// other relations which are selected are prioritized
+		for (GridElement other : Main.getHandlerForElement(this).getDrawPanel().getAllEntities()) {
+			Selector s = Main.getHandlerForElement(other).getDrawPanel().getSelector();
+			if (other != this && other instanceof Relation && s.isSelected(other)) {
+				int xDist = getRectangle().x - other.getRectangle().x;
+				int yDist = getRectangle().y - other.getRectangle().y;
+				Point modifiedP = new Point(p.x + xDist, p.y + yDist); // the point must be modified, because the other relation has other coordinates
+				boolean containsHelper = ((Relation) other).calcContains(modifiedP);
+				if (s.isSelected(other) && containsHelper) {
+					return false; 
+				}
+			}
+		}
+		return calcContains(Converter.convert(p));
+	}
 
-		float zoom = getHandler().getZoomFactor();
+	private boolean calcContains(Point p) {
+		float zoom = Main.getHandlerForElement(this).getZoomFactor();
 
 		for (int i = 0; i < getLinePoints().size(); i++) {
 			Point x = getLinePoints().elementAt(i);
-			if (pyth(p, x) < SELECTCIRCLESIZE * zoom) return true;
+			if (p.distance(x) < SELECTCIRCLESIZE * zoom) return true;
 		}
 
 		for (int i = 0; i < getLinePoints().size() - 1; i++) {
 			Point x1 = getLinePoints().elementAt(i);
 			Point x2 = getLinePoints().elementAt(i + 1);
 
-			if (pyth(p, x1) + pyth(p, x2) > pyth(x1, x2) + 5) continue;
+			if (p.distance(x1) + p.distance(x2) > x1.distance(x2) + 5) continue;
 
 			// system origin translated to x1
 			double p1x = x2.getX() - x1.getX();
@@ -725,7 +718,7 @@ public class Relation extends GridElement {
 
 	@Override
 	public boolean contains(int x, int y) {
-		return contains(new Point(x, y));
+		return contains(new java.awt.Point(x, y));
 	}
 
 	private Vector<Point> _points;
@@ -736,9 +729,11 @@ public class Relation extends GridElement {
 		}
 		return _points;
 	}
-
-	public void setLinePoints(Vector<Point> v) {
-		_points = v;
+	
+	public void moveLinePoint(int index, int diffx, int diffy) {
+		Point p = getLinePoints().elementAt(index);
+		p.move(diffx, diffy);
+		repaint();
 	}
 
 	@Override
@@ -749,8 +744,8 @@ public class Relation extends GridElement {
 		c.setAdditionalAttributes(this.getAdditionalAttributes());
 
 		c.setVisible(true);
-		c.setBounds(this.getBounds());
-		c.setHandler(this.getHandler());
+		c.setRectangle(this.getRectangle());
+		Main.getHandlerForElement(this).setHandlerAndInitListeners(c);
 
 		return c;
 	}
@@ -762,7 +757,7 @@ public class Relation extends GridElement {
 	// Polygon to draw the move whole line rectangle + check if it contains the mouse
 	public Polygon getWholeLinePolygon() {
 
-		float zoom = getHandler().getZoomFactor();
+		float zoom = Main.getHandlerForElement(this).getZoomFactor();
 
 		Polygon p = new Polygon();
 		Point mid;
@@ -803,11 +798,11 @@ public class Relation extends GridElement {
 	@Override
 	public void paintEntity(Graphics g) {
 
-		float zoom = getHandler().getZoomFactor();
+		float zoom = Main.getHandlerForElement(this).getZoomFactor();
 
 		Graphics2D g2 = (Graphics2D) g;
-		g2.setFont(this.getHandler().getFontHandler().getFont());
-		Composite[] composites = colorize(g2); // enable colors
+		g2.setFont(Main.getHandlerForElement(this).getFontHandler().getFont());
+		colorize(g2); // enable colors
 		g2.setColor(fgColor);
 		// Just to set anti-aliasing, even if no text
 		// operations occur
@@ -826,18 +821,18 @@ public class Relation extends GridElement {
 		endShapes.add(new NoShape());
 
 		if ((beginQualifier != null) && (beginQualifier.length() > 0)) {
-			TextLayout tl = new TextLayout(beginQualifier, this.getHandler().getFontHandler().getFont(), Constants.FRC);
+			TextLayout tl = new TextLayout(beginQualifier, Main.getHandlerForElement(this).getFontHandler().getFont(), g2.getFontRenderContext());
 			Qualifier q = new Qualifier(beginQualifier, 0, 0, (int) tl.getBounds().getWidth()
-					+ (int) this.getHandler().getFontHandler().getFontSize() * 2, (int) tl.getBounds().getHeight()
-					+ (int) this.getHandler().getFontHandler().getFontSize() / 2);
+					+ (int) Main.getHandlerForElement(this).getFontHandler().getFontSize() * 2, (int) tl.getBounds().getHeight()
+					+ (int) Main.getHandlerForElement(this).getFontHandler().getFontSize() / 2);
 			startShapes.add(q);
 		}
 		if ((endQualifier != null) && (endQualifier.length() > 0)) {
-			TextLayout tl = new TextLayout(endQualifier, this.getHandler().getFontHandler().getFont(),
-					Constants.FRC);
+			TextLayout tl = new TextLayout(endQualifier, Main.getHandlerForElement(this).getFontHandler().getFont(),
+					g2.getFontRenderContext());
 			Qualifier q = new Qualifier(endQualifier, 0, 0, (int) tl.getBounds().getWidth()
-					+ (int) this.getHandler().getFontHandler().getFontSize() * 2, (int) tl.getBounds().getHeight()
-					+ (int) this.getHandler().getFontHandler().getFontSize() / 2);
+					+ (int) Main.getHandlerForElement(this).getFontHandler().getFontSize() * 2, (int) tl.getBounds().getHeight()
+					+ (int) Main.getHandlerForElement(this).getFontHandler().getFontSize() / 2);
 			endShapes.add(q);
 		}
 		if ((beginArrow != null) && (beginArrow.length() > 0)) {
@@ -849,48 +844,48 @@ public class Relation extends GridElement {
 			endShapes.add(a);
 		}
 		if ((beginMultiplicity != null) && (beginMultiplicity.length() > 0)) {
-			EmptyShape e = new EmptyShape((int) this.getHandler().getFontHandler().getFontSize());
+			EmptyShape e = new EmptyShape((int) Main.getHandlerForElement(this).getFontHandler().getFontSize());
 			startShapes.add(e);
-			TextLayout tl = new TextLayout(beginMultiplicity, this.getHandler().getFontHandler().getFont(), Constants.FRC);
+			TextLayout tl = new TextLayout(beginMultiplicity, Main.getHandlerForElement(this).getFontHandler().getFont(), g2.getFontRenderContext());
 			Multiplicity m = new Multiplicity(beginMultiplicity, 0, 0, (int) tl.getBounds().getWidth(),
 					(int) tl.getBounds().getHeight());
 			startShapes.add(m);
 		}
 		if ((endMultiplicity != null) && (endMultiplicity.length() > 0)) {
-			EmptyShape e = new EmptyShape((int) this.getHandler().getFontHandler().getFontSize());
+			EmptyShape e = new EmptyShape((int) Main.getHandlerForElement(this).getFontHandler().getFontSize());
 			endShapes.add(e);
-			TextLayout tl = new TextLayout(endMultiplicity, this.getHandler().getFontHandler().getFont(), Constants.FRC);
+			TextLayout tl = new TextLayout(endMultiplicity, Main.getHandlerForElement(this).getFontHandler().getFont(), g2.getFontRenderContext());
 			Multiplicity m = new Multiplicity(endMultiplicity, 0, 0, (int) tl.getBounds().getWidth(),
 					(int) tl.getBounds().getHeight());
 			endShapes.add(m);
 		}
 		if ((beginRole != null) && (beginRole.length() > 0)) {
-			EmptyShape e = new EmptyShape((int) this.getHandler().getFontHandler().getFontSize());
+			EmptyShape e = new EmptyShape((int) Main.getHandlerForElement(this).getFontHandler().getFontSize());
 			startShapes.add(e);
 			// A.Mueller start
 			// calculating the width if we break lines...
 
 			int position = 0;
 			int lineBreaks = 0;
-			double broadestText = this.getHandler().getFontHandler().getTextWidth(beginRole);
+			double broadestText = Main.getHandlerForElement(this).getFontHandler().getTextWidth(beginRole);
 			while (position != 1) {
 				int positionNew = beginRole.indexOf("\\\\", position);
 				if ((position == 0) && (positionNew != -1)) broadestText = 0;
 
 				if (positionNew != -1) {
 
-					broadestText = Math.max(broadestText, this.getHandler().getFontHandler()
+					broadestText = Math.max(broadestText, Main.getHandlerForElement(this).getFontHandler()
 							.getTextWidth(beginRole.substring(position,
 									positionNew)));
-					if (beginRole.lastIndexOf("\\\\") + 2 != beginRole.length()) broadestText = Math.max(broadestText, this.getHandler().getFontHandler().getTextWidth(beginRole.substring(beginRole.lastIndexOf("\\\\") + 2, beginRole.length())));
+					if (beginRole.lastIndexOf("\\\\") + 2 != beginRole.length()) broadestText = Math.max(broadestText, Main.getHandlerForElement(this).getFontHandler().getTextWidth(beginRole.substring(beginRole.lastIndexOf("\\\\") + 2, beginRole.length())));
 					lineBreaks++;
 				}
 
 				position = positionNew + 2;
 			}
 			Role r = new Role(beginRole, 0, 0, (int) broadestText, lineBreaks
-					* (int) this.getHandler().getFontHandler().getFontSize() + (lineBreaks + 2)
-					* (int) this.getHandler().getFontHandler().getDistanceBetweenTexts());
+					* (int) Main.getHandlerForElement(this).getFontHandler().getFontSize() + (lineBreaks + 2)
+					* (int) Main.getHandlerForElement(this).getFontHandler().getDistanceBetweenTexts());
 
 			// <OLDCODE>
 			/*
@@ -903,22 +898,22 @@ public class Relation extends GridElement {
 			startShapes.add(r);
 		}
 		if ((endRole != null) && (endRole.length() > 0)) {
-			EmptyShape e = new EmptyShape((int) this.getHandler().getFontHandler().getFontSize());
+			EmptyShape e = new EmptyShape((int) Main.getHandlerForElement(this).getFontHandler().getFontSize());
 			endShapes.add(e);
 			// A.Mueller start
 			// calculating the width if we break lines...
 			int position = 0;
 			int lineBreaks = 0;
-			double broadestText = this.getHandler().getFontHandler().getTextWidth(endRole);
+			double broadestText = Main.getHandlerForElement(this).getFontHandler().getTextWidth(endRole);
 			while (position != 1) {
 				int positionNew = endRole.indexOf("\\\\", position);
 				if ((position == 0) && (positionNew != -1)) broadestText = 0;
 
 				if (positionNew != -1) {
 
-					broadestText = Math.max(broadestText, this.getHandler().getFontHandler().getTextWidth(endRole.substring(position, positionNew)));
+					broadestText = Math.max(broadestText, Main.getHandlerForElement(this).getFontHandler().getTextWidth(endRole.substring(position, positionNew)));
 					if (endRole.lastIndexOf("\\\\") + 2 != endRole.length()) broadestText = Math.max(broadestText,
-							this.getHandler().getFontHandler().getTextWidth(endRole.substring(endRole.lastIndexOf("\\\\") + 2,
+							Main.getHandlerForElement(this).getFontHandler().getTextWidth(endRole.substring(endRole.lastIndexOf("\\\\") + 2,
 									endRole.length())));
 					lineBreaks++;
 				}
@@ -926,8 +921,8 @@ public class Relation extends GridElement {
 				position = positionNew + 2;
 			}
 			Role r = new Role(endRole, 0, 0, (int) broadestText, lineBreaks
-					* (int) this.getHandler().getFontHandler().getFontSize() + (lineBreaks + 2)
-					* (int) this.getHandler().getFontHandler().getDistanceBetweenTexts());
+					* (int) Main.getHandlerForElement(this).getFontHandler().getFontSize() + (lineBreaks + 2)
+					* (int) Main.getHandlerForElement(this).getFontHandler().getDistanceBetweenTexts());
 
 			// <OLDCODE>
 			/*
@@ -942,18 +937,18 @@ public class Relation extends GridElement {
 		// G.Mueller start
 		if ((beginPort != null) && (beginPort.length() > 0)) {
 
-			EmptyShape e = new EmptyShape((int) this.getHandler().getFontHandler().getFontSize());
+			EmptyShape e = new EmptyShape((int) Main.getHandlerForElement(this).getFontHandler().getFontSize());
 			startShapes.add(e);
-			TextLayout tl = new TextLayout(beginPort, this.getHandler().getFontHandler().getFont(), Constants.FRC);
+			TextLayout tl = new TextLayout(beginPort, Main.getHandlerForElement(this).getFontHandler().getFont(), g2.getFontRenderContext());
 			Port p = new Port(beginPort, 0, 0, (int) tl.getBounds().getWidth(), (int) tl.getBounds().getHeight());
 
 			startShapes.add(p);
 
 		}
 		if ((endPort != null) && (endPort.length() > 0)) {
-			EmptyShape e = new EmptyShape((int) this.getHandler().getFontHandler().getFontSize());
+			EmptyShape e = new EmptyShape((int) Main.getHandlerForElement(this).getFontHandler().getFontSize());
 			endShapes.add(e);
-			TextLayout tl = new TextLayout(endPort, this.getHandler().getFontHandler().getFont(), Constants.FRC);
+			TextLayout tl = new TextLayout(endPort, Main.getHandlerForElement(this).getFontHandler().getFont(), g2.getFontRenderContext());
 			Port p = new Port(endPort, 0, 0, (int) tl.getBounds().getWidth(), (int) tl.getBounds().getHeight());
 			endShapes.add(p);
 		}
@@ -973,11 +968,11 @@ public class Relation extends GridElement {
 
 		if (lineType.equals("-.")) g2.setStroke(Utils.getStroke(LineType.SOLID, 1));
 		else if (lineType.equals(".-")) g2.setStroke(Utils.getStroke(LineType.DASHED, 1));
-		else if (lineType.equals("-")) g2.setStroke(Utils.getStroke(LineType.SOLID, 1));
-		else if (lineType.equals(".")) g2.setStroke(Utils.getStroke(LineType.DASHED, 1));
-		else if (lineType.equals("=")) g2.setStroke(Utils.getStroke(LineType.DOUBLE, 1));
-		else if (lineType.equals(":")) g2.setStroke(Utils.getStroke(LineType.DOUBLE_DASHED, 1));
-		else if (lineType.equals("::")) g2.setStroke(Utils.getStroke(LineType.DOUBLE_DOTTED, 1));
+		else if (lineType.equals(LineType.SOLID.getValue())) g2.setStroke(Utils.getStroke(LineType.SOLID, 1));
+		else if (lineType.equals(LineType.DASHED.getValue())) g2.setStroke(Utils.getStroke(LineType.DASHED, 1));
+		else if (lineType.equals(LineType.DOUBLE.getValue())) g2.setStroke(Utils.getStroke(LineType.DOUBLE, 1));
+		else if (lineType.equals(LineType.DOUBLE_DASHED.getValue())) g2.setStroke(Utils.getStroke(LineType.DOUBLE_DASHED, 1));
+		else if (lineType.equals(LineType.DOUBLE_DOTTED.getValue())) g2.setStroke(Utils.getStroke(LineType.DOUBLE_DOTTED, 1));
 
 		for (int i = 0; i < getLinePoints().size() - 1; i++) {
 
@@ -1183,7 +1178,7 @@ public class Relation extends GridElement {
 		}
 
 		g2.setStroke(Utils.getStroke(LineType.SOLID, 1));
-		if (isSelected && !this.isPartOfGroup()) {
+		if (Main.getHandlerForElement(this).getDrawPanel().getSelector().isSelected(this) && !this.isPartOfGroup()) {
 			for (int i = 0; i < getLinePoints().size(); i++) {
 				Point p = getLinePoints().elementAt(i);
 				int start = (int) ((SELECTCIRCLESIZE / 15 * 10) * zoom);
@@ -1210,9 +1205,9 @@ public class Relation extends GridElement {
 				g.setColor(fgColor);
 				// end
 				g.drawRect((int) r.getX(), (int) r.getY(), (int) r.getWidth(), (int) r.getHeight());
-				this.getHandler().getFontHandler().writeText(g2, q.getString(), (int) r.getX()
-						+ (int) this.getHandler().getFontHandler().getFontSize(), (int) r.getY()
-						+ (int) this.getHandler().getFontHandler().getFontSize(), false);
+				Main.getHandlerForElement(this).getFontHandler().writeText(g2, q.getString(), (int) r.getX()
+				+ (int) Main.getHandlerForElement(this).getFontHandler().getFontSize(), (int) r.getY()
+				+ (int) Main.getHandlerForElement(this).getFontHandler().getFontSize(), AlignHorizontal.LEFT);
 
 			}
 			else if (r instanceof Arrow) {
@@ -1425,11 +1420,11 @@ public class Relation extends GridElement {
 
 					// if (beginCSDArrow.equals("compStart")) {
 					if (beginArrow.startsWith("compStart")) {
-						getHandler().getFontHandler().setFontSize(10);
+						Main.getHandlerForElement(this).getFontHandler().setFontSize((double) 10);
 
 						s = boxSize;
 
-						if (!csdStartText.equals("")) s = this.getHandler().getFontHandler().getTextWidth(csdStartText);
+						if (!csdStartText.equals("")) s = (int) Main.getHandlerForElement(this).getFontHandler().getTextWidth(csdStartText);
 						if (s < boxSize) s = boxSize;
 
 						px1 = getStartPoint();
@@ -1466,7 +1461,7 @@ public class Relation extends GridElement {
 						}
 						else {
 							if (!csdStartText.equals("")) {
-								this.getHandler().getFontHandler().writeText(g2, csdStartText, px1.x, px1.y + (int) (6 * zoom), true);
+								Main.getHandlerForElement(this).getFontHandler().writeText(g2, csdStartText, px1.x, px1.y + (int) (6 * zoom), AlignHorizontal.CENTER);
 							}
 						}
 
@@ -1484,16 +1479,16 @@ public class Relation extends GridElement {
 							g2.setTransform(at);
 						}
 
-						getHandler().getFontHandler().resetFontSize();
+						Main.getHandlerForElement(this).getFontHandler().resetFontSize();
 					}
 
 					// if (endCSDArrow.equals("compEnd")) {
 					if (endArrow.startsWith("compEnd")) {
-						getHandler().getFontHandler().setFontSize(10);
+						Main.getHandlerForElement(this).getFontHandler().setFontSize(10.0);
 
 						s = boxSize;
 
-						if (!csdEndText.equals("")) s = this.getHandler().getFontHandler().getTextWidth(csdEndText);
+						if (!csdEndText.equals("")) s = (int) Main.getHandlerForElement(this).getFontHandler().getTextWidth(csdEndText);
 						if (s < boxSize) s = boxSize;
 
 						px1 = getEndPoint();
@@ -1531,7 +1526,7 @@ public class Relation extends GridElement {
 						}
 						else {
 							if (!csdEndText.equals("")) {
-								this.getHandler().getFontHandler().writeText(g2, csdEndText, px1.x, px1.y + (int) (6 * zoom), true);
+								Main.getHandlerForElement(this).getFontHandler().writeText(g2, csdEndText, px1.x, px1.y + (int) (6 * zoom), AlignHorizontal.CENTER);
 							}
 						}
 
@@ -1549,7 +1544,7 @@ public class Relation extends GridElement {
 							g2.setTransform(at);
 						}
 
-						getHandler().getFontHandler().resetFontSize();
+						Main.getHandlerForElement(this).getFontHandler().resetFontSize();
 					}
 
 				}
@@ -1560,8 +1555,8 @@ public class Relation extends GridElement {
 				Multiplicity m = (Multiplicity) r;
 				// g.drawRect((int)r.getX(), (int)r.getY(), (int)r.getWidth(),
 				// (int)r.getHeight());
-				this.getHandler().getFontHandler().writeText(g2, m.getString(), (int) r.getX(), (int) r.getY()
-						+ (int) this.getHandler().getFontHandler().getFontSize() + 2 * (int) this.getHandler().getFontHandler().getDistanceBetweenTexts(), false); // B. Buckl
+				Main.getHandlerForElement(this).getFontHandler().writeText(g2, m.getString(), (int) r.getX(), (int) r.getY()
+				+ (int) Main.getHandlerForElement(this).getFontHandler().getFontSize() + 2 * (int) Main.getHandlerForElement(this).getFontHandler().getDistanceBetweenTexts(), AlignHorizontal.LEFT); // B. Buckl
 				// added
 				// +2*this.getHandler().getDistTextToText()
 			}
@@ -1570,19 +1565,19 @@ public class Relation extends GridElement {
 				String str = role.getString();
 
 				int position = 0;
-				int y = 4 * (int) this.getHandler().getFontHandler().getDistanceBetweenTexts();
+				int y = 4 * (int) Main.getHandlerForElement(this).getFontHandler().getDistanceBetweenTexts();
 				while (position != -1) {
 					position = str.indexOf("\\\\");
 
 					if (position != -1) {
 						String s = str.substring(0, position);
-						this.getHandler().getFontHandler().writeText(g2, s, (int) r.getX(), (int) r.getY() + y, false);
+						Main.getHandlerForElement(this).getFontHandler().writeText(g2, s, (int) r.getX(), (int) r.getY() + y, AlignHorizontal.LEFT);
 
-						y = y + (int) this.getHandler().getFontHandler().getFontSize();
+						y = y + (int) Main.getHandlerForElement(this).getFontHandler().getFontSize();
 						str = str.substring(position + 2, str.length());
 					}
 					else {
-						this.getHandler().getFontHandler().writeText(g2, str, (int) r.getX(), (int) r.getY() + y, false);
+						Main.getHandlerForElement(this).getFontHandler().writeText(g2, str, (int) r.getX(), (int) r.getY() + y, AlignHorizontal.LEFT);
 
 					}
 
@@ -1602,9 +1597,7 @@ public class Relation extends GridElement {
 			else if (r instanceof Port) {
 				Port p = (Port) r;
 
-				this.getHandler().getFontHandler().writeText(g2, p.getString(),
-						(int) (r.getX()),
-						(int) (r.getY()), false);
+				Main.getHandlerForElement(this).getFontHandler().writeText(g2, p.getString(), (int) (r.getX()), (int) (r.getY()), AlignHorizontal.LEFT);
 
 			}
 			// G.Mueller end
@@ -1613,7 +1606,7 @@ public class Relation extends GridElement {
 		if (this.getStrings() != null) {
 			if (this.getStrings().size() > 0) {
 				Point start = this.getCenterOfLine();
-				int yPos = start.y - (int) this.getHandler().getFontHandler().getDistanceBetweenTexts(); // B. Buckl
+				int yPos = start.y - (int) Main.getHandlerForElement(this).getFontHandler().getDistanceBetweenTexts(); // B. Buckl
 				// added
 				// -this.getHandler().getDistTextToText()
 				int xPos = start.x;
@@ -1628,14 +1621,14 @@ public class Relation extends GridElement {
 								|| ((s.indexOf("<") == s.lastIndexOf("<")) && (s.indexOf("<") != -1))) {
 							// decide where and what to draw...
 							int fontHeight = g2.getFontMetrics(
-									this.getHandler().getFontHandler().getFont()).getHeight()
-									- g2.getFontMetrics(this.getHandler().getFontHandler().getFont()).getDescent()
-									- g2.getFontMetrics(this.getHandler().getFontHandler().getFont()).getLeading();
+									Main.getHandlerForElement(this).getFontHandler().getFont()).getHeight()
+									- g2.getFontMetrics(Main.getHandlerForElement(this).getFontHandler().getFont()).getDescent()
+									- g2.getFontMetrics(Main.getHandlerForElement(this).getFontHandler().getFont()).getLeading();
 							fontHeight = fontHeight / 3 * 2;
 
 							if (s.endsWith(">")) {
 								s = s.substring(0, s.length() - 1);
-								int fontWidth = this.getHandler().getFontHandler().getTextWidth(s);
+								int fontWidth = (int) Main.getHandlerForElement(this).getFontHandler().getTextWidth(s);
 								xPos = xPos - (fontHeight + 4) / 2;
 								int startDrawX = xPos + fontWidth / 2 + 4;
 								Polygon temp = new Polygon();
@@ -1647,7 +1640,7 @@ public class Relation extends GridElement {
 							}
 							else if (s.endsWith("<")) {
 								s = s.substring(0, s.length() - 1);
-								int fontWidth = this.getHandler().getFontHandler().getTextWidth(s);
+								int fontWidth = (int) Main.getHandlerForElement(this).getFontHandler().getTextWidth(s);
 								xPos = xPos - (fontHeight + 4) / 2;
 								int startDrawX = xPos + fontWidth / 2 + 4;
 								Polygon temp = new Polygon();
@@ -1658,7 +1651,7 @@ public class Relation extends GridElement {
 							}
 							else if (s.startsWith(">")) {
 								s = s.substring(1, s.length());
-								int fontWidth = this.getHandler().getFontHandler().getTextWidth(s);
+								int fontWidth = (int) Main.getHandlerForElement(this).getFontHandler().getTextWidth(s);
 								xPos = xPos + (fontHeight + 4) / 2;
 								int startDrawX = xPos - fontWidth / 2 - 4;
 								Polygon temp = new Polygon();
@@ -1669,7 +1662,7 @@ public class Relation extends GridElement {
 							}
 							else if (s.startsWith("<")) {
 								s = s.substring(1, s.length());
-								int fontWidth = this.getHandler().getFontHandler().getTextWidth(s);
+								int fontWidth = (int) Main.getHandlerForElement(this).getFontHandler().getTextWidth(s);
 								xPos = xPos + (fontHeight + 4) / 2;
 								int startDrawX = xPos - fontWidth / 2 - 4;
 								Polygon temp = new Polygon();
@@ -1685,9 +1678,9 @@ public class Relation extends GridElement {
 					}
 					// A.Mueller end...
 
-					this.getHandler().getFontHandler().writeText(g2, s, xPos, yPos, true);
-					yPos += (int) this.getHandler().getFontHandler().getFontSize();
-					yPos += this.getHandler().getFontHandler().getDistanceBetweenTexts();
+					Main.getHandlerForElement(this).getFontHandler().writeText(g2, s, xPos, yPos, AlignHorizontal.CENTER);
+					yPos += (int) Main.getHandlerForElement(this).getFontHandler().getFontSize();
+					yPos += Main.getHandlerForElement(this).getFontHandler().getDistanceBetweenTexts();
 				}
 			}
 		}
@@ -1717,11 +1710,11 @@ public class Relation extends GridElement {
 				int xPos = start.x;
 				for (int i = 0; i < getStrings().size(); i++) {
 					String s = this.getStrings().elementAt(i);
-					int width = this.getHandler().getFontHandler().getTextWidth(s);
-					criticalPoints.add(new Point(xPos - width / 2 - (int) (20 * zoom), yPos - (int) this.getHandler().getFontHandler().getFontSize() - (int) (20 * zoom)));
+					int width = (int) Main.getHandlerForElement(this).getFontHandler().getTextWidth(s);
+					criticalPoints.add(new Point(xPos - width / 2 - (int) (20 * zoom), yPos - (int) Main.getHandlerForElement(this).getFontHandler().getFontSize() - (int) (20 * zoom)));
 					criticalPoints.add(new Point(xPos + width / 2 + (int) (20 * zoom), yPos + (int) (20 * zoom)));
-					yPos += (int) this.getHandler().getFontHandler().getFontSize();
-					yPos += this.getHandler().getFontHandler().getDistanceBetweenTexts();
+					yPos += (int) Main.getHandlerForElement(this).getFontHandler().getFontSize();
+					yPos += Main.getHandlerForElement(this).getFontHandler().getDistanceBetweenTexts();
 				}
 			}
 		}
@@ -1759,7 +1752,7 @@ public class Relation extends GridElement {
 
 		// BUGFIX ZOOM: We must consider the gridsize for the min and max value to avoid rounding errors
 		// Therefore we subtract or add the difference to the next possible value
-		int gridSize = this.getHandler().getGridSize();
+		int gridSize = Main.getHandlerForElement(this).getGridSize();
 
 		minx -= (minx % gridSize);
 		miny -= (miny % gridSize);
@@ -1772,10 +1765,10 @@ public class Relation extends GridElement {
 		maxy += (maxy % gridSize);
 
 		if ((maxx != 0) || (maxy != 0)) {
-			this.changeSize(maxx - getWidth(), maxy - getHeight());
+			this.changeSize(maxx - getRectangle().width, maxy - getRectangle().height);
 		}
 		if ((minx != 0) | (miny != 0)) {
-			this.changeLocation(minx, miny);
+			this.setLocationDifference(minx, miny);
 			this.changeSize(-minx, -miny);
 			for (int i = 0; i < getLinePoints().size(); i++) {
 				Point p = getLinePoints().elementAt(i);
@@ -1797,24 +1790,24 @@ public class Relation extends GridElement {
 		return ret;
 	}
 
-	public Point getAbsoluteCoorStart() {
-		Point ret = new Point();
-		ret.x = this.getX() + this.getStartPoint().x;
-		ret.y = this.getY() + this.getStartPoint().y;
+	public PointDouble getAbsoluteCoorStart() {
+		PointDouble ret = new PointDouble();
+		ret.x = this.getRectangle().x + this.getStartPoint().x;
+		ret.y = this.getRectangle().y + this.getStartPoint().y;
 		return ret;
 	}
 
-	public Point getAbsoluteCoorEnd() {
-		Point ret = new Point();
-		ret.x = this.getX() + this.getEndPoint().x;
-		ret.y = this.getY() + this.getEndPoint().y;
+	public PointDouble getAbsoluteCoorEnd() {
+		PointDouble ret = new PointDouble();
+		ret.x = this.getRectangle().x + this.getEndPoint().x;
+		ret.y = this.getRectangle().y + this.getEndPoint().y;
 		return ret;
 	}
 
 	// G.Mueller start
 	public String[] getCSDText(String str) { // for the Composite Structure Diagram Text
 
-		String tmp[] = new String[4];
+		String[] tmp = new String[4];
 		int to = 0;
 		int from = 0;
 		tmp[0] = " ";
@@ -1855,4 +1848,20 @@ public class Relation extends GridElement {
 		return null;
 	}
 
+	public boolean allPointsOnSamePos() {
+		Point first = null;
+		for (Point p : this.getLinePoints()) {
+			if (first == null) {
+				first = p;
+			}
+			else {
+				if (first.x != p.x || first.y != p.y) {
+//					System.out.println(first + " // " + p);
+					return false;
+				}
+			}
+		}
+		return true;
+	}
+
 }
