@@ -17,10 +17,13 @@ import java.util.Vector;
 import java.util.regex.Matcher;
 import java.util.regex.Pattern;
 
-import com.baselet.control.Constants.LineType;
+import com.baselet.control.Main;
 import com.baselet.control.Utils;
-import com.baselet.diagram.DiagramHandler;
-import com.baselet.diagram.FontHandler;
+import com.baselet.control.enumerations.AlignHorizontal;
+import com.baselet.control.enumerations.Direction;
+import com.baselet.control.enumerations.FormatLabels;
+import com.baselet.control.enumerations.LineType;
+import com.baselet.element.OldGridElement;
 
 
 // An interaction represents a synchronous/asynchronous message
@@ -47,9 +50,8 @@ class Interaction {
 	}
 
 	public boolean hasControl(int objNum) {
-		if ((srcObjHasControl && (srcObj == objNum)) ||
-				(destObjHasControl && (destObj == objNum))) return true;
-		else return false;
+		return (srcObjHasControl && (srcObj == objNum)) ||
+				(destObjHasControl && (destObj == objNum));
 	}
 
 	@Override
@@ -137,7 +139,7 @@ class InteractionManagement {
 }
 
 @SuppressWarnings("serial")
-public class SequenceDiagram extends com.baselet.element.GridElement {
+public class SequenceDiagram extends OldGridElement {
 
 	public int controlFlowBoxWidth = 20;
 
@@ -172,27 +174,21 @@ public class SequenceDiagram extends com.baselet.element.GridElement {
 
 	}
 
-	@Override
-	public void setHandler(DiagramHandler handler) {
-		super.setHandler(handler);
-		zoomValues();
-	}
-
 	@Override
 	public void paintEntity(Graphics g) {
 
 		zoomValues();
-		float zoom = getHandler().getZoomFactor();
+		float zoom = Main.getHandlerForElement(this).getZoomFactor();
 
 		// Some unimportant initialization stuff; setting color, font
 		// quality, etc. You should not have to change this.
 		Graphics2D g2 = (Graphics2D) g;
-		g2.setFont(this.getHandler().getFontHandler().getFont());
+		g2.setFont(Main.getHandlerForElement(this).getFontHandler().getFont());
 		g2.setColor(fgColor);
 		
 
 		// draw the border
-		g2.drawRect(0, 0, this.getWidth() - 1, this.getHeight() - 1);
+		g2.drawRect(0, 0, this.getRectangle().width - 1, this.getRectangle().height - 1);
 
 		levelNum = 1;
 
@@ -202,9 +198,9 @@ public class SequenceDiagram extends com.baselet.element.GridElement {
 		if (lines.elementAt(0).startsWith("title:")) {
 			String title = lines.elementAt(0).substring("title:".length());
 			if ((title != null) && (title.length() > 0)) {
-				this.getHandler().getFontHandler().writeText(g2, title, (int) (5 * zoom), (int) this.getHandler().getFontHandler().getFontSize() + (int) this.getHandler().getFontHandler().getDistanceBetweenTexts(), false);
-				int titlewidth = this.getHandler().getFontHandler().getTextWidth(title);
-				int ty = (int) (8 * zoom) + (int) (this.getHandler().getFontHandler().getFontSize() + this.getHandler().getFontHandler().getDistanceBetweenTexts());
+				Main.getHandlerForElement(this).getFontHandler().writeText(g2, title, (int) (5 * zoom), (int) Main.getHandlerForElement(this).getFontHandler().getFontSize() + (int) Main.getHandlerForElement(this).getFontHandler().getDistanceBetweenTexts(), AlignHorizontal.LEFT);
+				int titlewidth = (int) Main.getHandlerForElement(this).getFontHandler().getTextWidth(title);
+				int ty = (int) (8 * zoom) + (int) (Main.getHandlerForElement(this).getFontHandler().getFontSize() + Main.getHandlerForElement(this).getFontHandler().getDistanceBetweenTexts());
 				g2.drawLine(0, ty, titlewidth + (int) (10 * zoom), ty);
 				g2.drawLine(titlewidth + (int) (10 * zoom), ty, titlewidth + ty + (int) (10 * zoom), 0);
 				lines.remove(0);
@@ -228,6 +224,8 @@ public class SequenceDiagram extends com.baselet.element.GridElement {
 			levelNum++;
 		}
 
+		if (lines.size() == 0) return; // return if it only has the title line (Issue 146)
+		
 		String firstLine = lines.elementAt(0);
 		Vector<String> obj = Utils.decomposeStrings(firstLine, "|");
 		int numObjects = obj.size();
@@ -403,16 +401,16 @@ public class SequenceDiagram extends com.baselet.element.GridElement {
 		double maxHeight = 0;
 		for (int i = 0; i < numObjects; i++) {
 			String s = obj.elementAt(i);
-			if (s.startsWith(FontHandler.FormatLabels.UNDERLINE) && s.endsWith(FontHandler.FormatLabels.UNDERLINE) && (s.length() > 2)) {
+			if (s.startsWith(FormatLabels.UNDERLINE.getValue()) && s.endsWith(FormatLabels.UNDERLINE.getValue()) && (s.length() > 2)) {
 				s = s.substring(1, s.length() - 1);
 			}
-			TextLayout layout = new TextLayout(s, this.getHandler().getFontHandler().getFont(), g2.getFontRenderContext());
+			TextLayout layout = new TextLayout(s, Main.getHandlerForElement(this).getFontHandler().getFont(), g2.getFontRenderContext());
 			maxWidth = Math.max(layout.getBounds().getWidth(), maxWidth);
 			maxHeight = Math.max(layout.getBounds().getHeight(), maxHeight);
 		}
 
-		rectWidth = (int) Math.floor(maxWidth + 1) + 2 * (int) this.getHandler().getFontHandler().getDistanceBetweenTexts() + (int) this.getHandler().getFontHandler().getFontSize();
-		rectHeight = (int) Math.floor(maxHeight + 1) + (int) this.getHandler().getFontHandler().getDistanceBetweenTexts() + (int) this.getHandler().getFontHandler().getFontSize();
+		rectWidth = (int) Math.floor(maxWidth + 1) + 2 * (int) Main.getHandlerForElement(this).getFontHandler().getDistanceBetweenTexts() + (int) Main.getHandlerForElement(this).getFontHandler().getFontSize();
+		rectHeight = (int) Math.floor(maxHeight + 1) + (int) Main.getHandlerForElement(this).getFontHandler().getDistanceBetweenTexts() + (int) Main.getHandlerForElement(this).getFontHandler().getFontSize();
 
 		// draw the first line of the sequence diagram
 		int ypos = borderDistance + yOffsetforTitle;
@@ -420,11 +418,11 @@ public class SequenceDiagram extends com.baselet.element.GridElement {
 		for (int i = 0; i < numObjects; i++) {
 			boolean underline = false;
 			String s = obj.elementAt(i);
-			if (s.startsWith(FontHandler.FormatLabels.UNDERLINE) && s.endsWith(FontHandler.FormatLabels.UNDERLINE) && (s.length() > 2)) {
+			if (s.startsWith(FormatLabels.UNDERLINE.getValue()) && s.endsWith(FormatLabels.UNDERLINE.getValue()) && (s.length() > 2)) {
 				underline = true;
 				s = s.substring(1, s.length() - 1);
 			}
-			TextLayout layout = new TextLayout(s, this.getHandler().getFontHandler().getFont(),
+			TextLayout layout = new TextLayout(s, Main.getHandlerForElement(this).getFontHandler().getFont(),
 					g2.getFontRenderContext());
 
 			g2.drawRect(xpos, ypos, rectWidth - 1, rectHeight - 1);
@@ -437,16 +435,16 @@ public class SequenceDiagram extends com.baselet.element.GridElement {
 			layout.draw(g2, tx, ty);
 
 			if (underline) g2.drawLine(tx,
-					ty + (int) this.getHandler().getFontHandler().getDistanceBetweenTexts() / 2,
+					ty + (int) Main.getHandlerForElement(this).getFontHandler().getDistanceBetweenTexts() / 2,
 					tx + (int) layout.getBounds().getWidth(),
-					ty + (int) this.getHandler().getFontHandler().getDistanceBetweenTexts() / 2);
+					ty + (int) Main.getHandlerForElement(this).getFontHandler().getDistanceBetweenTexts() / 2);
 
 			xpos += rectWidth + rectDistance;
 		}
 
 		// draw the messages
 		int maxTextXpos = drawMessages(g2);
-		maxTextXpos += 3 * this.getHandler().getFontHandler().getDistanceBetweenTexts(); // add extra space
+		maxTextXpos += 3 * Main.getHandlerForElement(this).getFontHandler().getDistanceBetweenTexts(); // add extra space
 		if (boxStrings.length() > 1) {
 			try {
 				drawControlFlowBoxesWithLines(g2, boxStrings.substring(1), numObjects); // LME: 1,2;1,2;... cut first ;-character
@@ -461,14 +459,14 @@ public class SequenceDiagram extends com.baselet.element.GridElement {
 		int rHeight = 2 * borderDistance + yOffsetforTitle + rectHeight + rectToFirstLevelDistance + levelNum * levelHeight;
 		rWidth = (rWidth > maxTextXpos ? rWidth : maxTextXpos);
 		// align the borders to the grid
-		rWidth += this.getHandler().getGridSize() - rWidth % this.getHandler().getGridSize();
-		rHeight += this.getHandler().getGridSize() - rHeight % this.getHandler().getGridSize();
+		rWidth += Main.getHandlerForElement(this).getGridSize() - rWidth % Main.getHandlerForElement(this).getGridSize();
+		rHeight += Main.getHandlerForElement(this).getGridSize() - rHeight % Main.getHandlerForElement(this).getGridSize();
 		setSize(rWidth, rHeight);
 	}
 
 	private int drawMessages(Graphics2D g2) {
 
-		float zoom = getHandler().getZoomFactor();
+		float zoom = Main.getHandlerForElement(this).getZoomFactor();
 
 		int maxTextXpos = 0;
 		for (int i = 0; i < im.getNumLevels(); i++) {
@@ -498,8 +496,8 @@ public class SequenceDiagram extends com.baselet.element.GridElement {
 						g2.drawLine(p1.x, p1.y, d2.x, d2.y);
 					}
 					else if (ia.getArrowKind() == SYNC) {
-						int xs[] = { p1.x, d1.x, d2.x };
-						int ys[] = { p1.y, d1.y, d2.y };
+						int[] xs = { p1.x, d1.x, d2.x };
+						int[] ys = { p1.y, d1.y, d2.y };
 						Color oldColor = g2.getColor();
 						g2.setColor(bgColor);
 						g2.fillPolygon(xs, ys, 3);
@@ -576,7 +574,7 @@ public class SequenceDiagram extends com.baselet.element.GridElement {
 			return 0;
 		}
 
-		Font font = this.getHandler().getFontHandler().getFont();
+		Font font = Main.getHandlerForElement(this).getFontHandler().getFont();
 		TextLayout layout = new TextLayout(methodName, font, g2.getFontRenderContext());
 
 		// draw it horizontally centered
@@ -709,19 +707,19 @@ public class SequenceDiagram extends com.baselet.element.GridElement {
 
 	private void drawInteractionFrame(Graphics2D g2, int pos1, int pos2, int recursionLevel, String text) {
 
-		float zoom = getHandler().getZoomFactor();
+		float zoom = Main.getHandlerForElement(this).getZoomFactor();
 
 		int pos11 = (pos1 + 1) * levelHeight + yOffsetforTitle;
 		int h = (pos2 - pos1) * levelHeight;
-		int x = (int) this.getHandler().getFontHandler().getDistanceBetweenTexts() * 2 + recursionLevel * 4;
-		g2.drawRect(x, pos11, this.getWidth() - (int) this.getHandler().getFontHandler().getDistanceBetweenTexts() * 4 - 1 - recursionLevel * 8, h);
-		int uLinePos = pos11 + (int) this.getHandler().getFontHandler().getDistanceBetweenTexts() + (int) (this.getHandler().getFontHandler().getFontSize() + (int) this.getHandler().getFontHandler().getDistanceBetweenTexts());
-		int textPos = pos11 + (int) this.getHandler().getFontHandler().getDistanceBetweenTexts() + (int) this.getHandler().getFontHandler().getFontSize();
+		int x = (int) Main.getHandlerForElement(this).getFontHandler().getDistanceBetweenTexts() * 2 + recursionLevel * 4;
+		g2.drawRect(x, pos11, this.getRectangle().width - (int) Main.getHandlerForElement(this).getFontHandler().getDistanceBetweenTexts() * 4 - 1 - recursionLevel * 8, h);
+		int uLinePos = pos11 + (int) Main.getHandlerForElement(this).getFontHandler().getDistanceBetweenTexts() + (int) (Main.getHandlerForElement(this).getFontHandler().getFontSize() + (int) Main.getHandlerForElement(this).getFontHandler().getDistanceBetweenTexts());
+		int textPos = pos11 + (int) Main.getHandlerForElement(this).getFontHandler().getDistanceBetweenTexts() + (int) Main.getHandlerForElement(this).getFontHandler().getFontSize();
 
 		int textWidth = 0;
 		if ((text == null) || text.equals("")) text = " ";
 		g2.drawString(text, x + (int) (10 * zoom), textPos);
-		int pW = this.getHandler().getFontHandler().getTextWidth(text);
+		int pW = (int) Main.getHandlerForElement(this).getFontHandler().getTextWidth(text);
 		textWidth = (pW > textWidth) ? (pW) : (textWidth);
 
 		g2.drawLine(x, uLinePos, x + textWidth + (int) (15 * zoom), uLinePos);
@@ -784,18 +782,18 @@ public class SequenceDiagram extends com.baselet.element.GridElement {
 	}
 
 	@Override
-	public int getPossibleResizeDirections() {
-		return 0;
-	} // deny size changes: dynamic resize is done by the diagram itself
+	public Set<Direction> getResizeArea(int x, int y) {
+		return new HashSet<Direction>(); // deny size changes
+	}
 
-	private void zoomValues() {
+	public void zoomValues() {
 
-		float zoom = getHandler().getZoomFactor();
+		float zoom = Main.getHandlerForElement(this).getZoomFactor();
 
 		controlFlowBoxWidth = (int) (20 * zoom);
 		rectDistance = (int) (60 * zoom);
-		rectHeight = 2 * (int) this.getHandler().getFontHandler().getDistanceBetweenTexts() + (int) this.getHandler().getFontHandler().getFontSize() + 10;
-		rectWidth = 2 * (int) this.getHandler().getFontHandler().getDistanceBetweenTexts() + (int) this.getHandler().getFontHandler().getFontSize() + 10;
+		rectHeight = 2 * (int) Main.getHandlerForElement(this).getFontHandler().getDistanceBetweenTexts() + (int) Main.getHandlerForElement(this).getFontHandler().getFontSize() + 10;
+		rectWidth = 2 * (int) Main.getHandlerForElement(this).getFontHandler().getDistanceBetweenTexts() + (int) Main.getHandlerForElement(this).getFontHandler().getFontSize() + 10;
 
 		borderDistance = (int) (10 * zoom);
 		levelHeight = (int) (30 * zoom);
