@@ -5,19 +5,20 @@ import java.awt.Graphics;
 import java.awt.Graphics2D;
 import java.util.Vector;
 
+import com.baselet.control.Main;
 import com.baselet.control.Utils;
-import com.baselet.element.GridElement;
+import com.baselet.element.OldGridElement;
 
 
 @SuppressWarnings("serial")
-public class InitialFinalState extends GridElement {
+public class InitialFinalState extends OldGridElement {
 	@Override
 	public void paintEntity(Graphics g) {
 
-		float zoom = getHandler().getZoomFactor();
+		float zoom = Main.getHandlerForElement(this).getZoomFactor();
 
 		Graphics2D g2 = (Graphics2D) g;
-		g2.setFont(this.getHandler().getFontHandler().getFont());
+		g2.setFont(Main.getHandlerForElement(this).getFontHandler().getFont());
 		g2.setColor(Color.red);
 		
 
@@ -30,12 +31,12 @@ public class InitialFinalState extends GridElement {
 		}
 
 		if (!initialState) {
-			g2.drawOval(0, 0, this.getWidth() - 1, this.getHeight() - 1);
+			g2.drawOval(0, 0, this.getRectangle().width - 1, this.getRectangle().height - 1);
 
-			g2.fillOval((int) (4 * zoom), (int) (4 * zoom), this.getWidth() - (int) (8 * zoom), this.getHeight() - (int) (8 * zoom));
+			g2.fillOval((int) (4 * zoom), (int) (4 * zoom), this.getRectangle().width - (int) (8 * zoom), this.getRectangle().height - (int) (8 * zoom));
 		}
 		else {
-			g2.fillOval(0, 0, this.getWidth(), this.getHeight());
+			g2.fillOval(0, 0, this.getRectangle().width, this.getRectangle().height);
 		}
 	}
 }
