@@ -4,6 +4,8 @@ package com.umlet.element.custom;
 import java.awt.Graphics;
 import java.awt.Graphics2D;
 
+import com.baselet.control.Main;
+
 @SuppressWarnings("serial")
 public class StateSubDiagram extends State {
 
@@ -11,10 +13,10 @@ public class StateSubDiagram extends State {
 	public void paintEntity(Graphics g) {
 		super.paintEntity(g);
 
-		float zoom = getHandler().getZoomFactor();
+		float zoom = Main.getHandlerForElement(this).getZoomFactor();
 		Graphics2D g2 = (Graphics2D) g;
-		int w = getWidth();
-		int h = getHeight();
+		int w = getRectangle().width;
+		int h = getRectangle().height;
 
 		// draw substate sign
 		g2.drawRoundRect(w - (int) (65 * zoom), h - (int) (16 * zoom), (int) (20 * zoom), (int) (10 * zoom), (int) (8 * zoom), (int) (8 * zoom));
