@@ -1,6 +1,6 @@
 package com.umlet.element.relation;
 
-import java.awt.Rectangle;
+import com.baselet.diagram.draw.geom.Rectangle;
 
 @SuppressWarnings("serial")
 public class Qualifier extends Rectangle {
